==> kdev-php-5.1.0.tar.xz: kdev-php-5.1.0/testprovider/kdevphpunitprovider.desktop.cmake <==
[Desktop Entry]
Type=Service
Exec=blubb
Comment=Finds and runs PHPUnit tests.
Comment[ar]=يعثر اختبارات PHPUnit ويشغّلها.
Comment[bs]=Traži i pokreće PHPUnit testove.
Comment[ca]=Cerca i executa proves de PHPUnit.
Comment[ca@valencia]=Busca i executa proves de PHPUnit.
Comment[da]=Finder og kører PHPUnit-tests.
Comment[de]=Sucht und führt PHPUnit-Tests aus.
Comment[el]=Βρίσκει και εκτελεί PHPUnit tests.
Comment[en_GB]=Finds and runs PHPUnit tests.
Comment[es]=Encuentra y ejecuta pruebas PHPUnit.
Comment[et]=PHPUniti testide leidmine ja käivitamine.
Comment[fi]=Etsii ja suorittaa PHPUnit-testejä
Comment[fr]=Trouve et exécute des tests « PHPUnit ».
Comment[ga]=Aimsigh agus rith tástálacha PHPUnit.
Comment[gl]=Atopa e executa probas de PHPUnit.
Comment[hu]=Megkeresi és lefuttatja a PHPUnit teszteket.
Comment[it]=Trova ed esegue i test PHPUnit
Comment[kk]=PHPUnit сынақтарды тауып жегу.
Comment[ko]=PHPUnit 테스트를 찾아서 실행합니다.
Comment[lt]=Randa ir vykdo PHPUnit testus.
Comment[mr]=पीएचपी-युनिट चाचण्या शोधतो व चालवतो.
Comment[nb]=Finner og kjører PHPUnit-tester.
Comment[nl]=Testen van PHPUnit vinden en uitvoeren.
Comment[pl]=Znajduje i uruchamia testy PHPUnit.
Comment[pt]=Procura e executa os testes do PHPUnit.
Comment[pt_BR]=Procura e executa os testes do PHPUnit.
Comment[ru]=Находит и запускает тесты PHPUnit
Comment[sk]=Nájde a spustí PHPUnit testy.
Comment[sl]=Najde in zažene preizkuse PHPUnit
Comment[sv]=Söker efter och kör PHPUnit-tester.
Comment[tr]=PHPUnit testlerini bulur ve çalıştırır.
Comment[uk]=Пошук і запуск перевірок PHPUnit.
Comment[x-test]=xxFinds and runs PHPUnit tests.xx
Comment[zh_CN]=查找并运行 PHPUnit 测试
Comment[zh_TW]=尋找並執行 PHPUnit 測試。
Name=PHPUnit Integration
Name[ar]=تكامل PHPUnit
Name[bs]=PHPUnit Integracija
Name[ca]=Integració PHPUnit
Name[ca@valencia]=Integració PHPUnit
Name[da]=Integration af PHPUnit
Name[de]=PHPUnit-Integration
Name[el]=PHPUnit Integration
Name[en_GB]=PHPUnit Integration
Name[es]=Integración de PHPUnit
Name[et]=PHPUniti lõimimine
Name[fi]=PHPUnit-integraatio
Name[fr]=Intégration de « PHPUnit »
Name[ga]=Comhtháthú PHPUnit
Name[gl]=Integración con PHPUnit
Name[hu]=PHPUnit integráció
Name[it]=Integrazione PHPUnit
Name[kk]=PHPUnit біріктіру
Name[ko]=PHPUnit 통합
Name[lt]=PHPUnit integracija
Name[mr]=पीएचपी-युनिट एकीकरण
Name[nb]=PHPUnit-integrering
Name[nl]=Integratie van PHPUnit
Name[pl]=Integracja PHPUnit
Name[pt]=Integração com o PHPUnit
Name[pt_BR]=Integração com o PHPUnit
Name[ru]=Интеграция PHPUnit
Name[sk]=Integrácia PHPUnit
Name[sl]=Podpora PHPUnit
Name[sv]=Integrering av PHPUnit
Name[tr]=PHPUnit Bütünleşmesi
Name[ug]=PHPUnit يۈرۈشلەشتۈرۈلۈشى
Name[uk]=Інтеграція PHPUnit
Name[x-test]=xxPHPUnit Integrationxx
Name[zh_CN]=PHPUnit 集成
Name[zh_TW]=PHPUnit 整合
GenericName=PHPUnit Integration
GenericName[ar]=تكامل PHPUnit
GenericName[bs]=PHPUnit Integracija
GenericName[ca]=Integració de PHPUnit
GenericName[ca@valencia]=Integració de PHPUnit
GenericName[da]=Integration af PHPUnit
GenericName[de]=PHPUnit-Integration
GenericName[el]=PHPUnit Integration
GenericName[en_GB]=PHPUnit Integration
GenericName[es]=Integración de PHPUnit
GenericName[et]=PHPUniti lõimimine
GenericName[fi]=PHPUnit-integraatio
GenericName[fr]=Intégration de « PHPUnit »
GenericName[ga]=Comhtháthú PHPUnit
GenericName[gl]=Integración con PHPUnit
GenericName[hu]=PHPUnit integráció
GenericName[it]=Integrazione PHPUnit
GenericName[kk]=PHPUnit біріктіру
GenericName[ko]=PHPUnit 통합
GenericName[lt]=PHPUnit integracija
GenericName[mr]=पीएचपी-युनिट एकीकरण
GenericName[nb]=PHPUnit-integrering
GenericName[nl]=Integratie van PHPUnit
GenericName[pl]=Integracja PHPUnit
GenericName[pt]=Integração com o PHPUnit
GenericName[pt_BR]=Integração com o PHPUnit
GenericName[ru]=Интеграция PHPUnit
GenericName[sk]=Integrácia PHPUnit
GenericName[sl]=Podpora PHPUnit
GenericName[sv]=Integrering av PHPUnit
GenericName[tr]=PHPUnit Bütünleşmesi
GenericName[ug]=PHPUnit يۈرۈشلەشتۈرۈلۈشى
GenericName[uk]=Інтеграція PHPUnit
GenericName[x-test]=xxPHPUnit Integrationxx
GenericName[zh_CN]=PHPUnit 集成
GenericName[zh_TW]=PHPUnit 整合
Icon=php
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevplatform/@KDEV_PLUGIN_VERSION@/kdevphpunitprovider
X-KDE-PluginInfo-Name=kdevphpunitprovider
X-KDE-PluginInfo-Author=Miha Čančula
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Testing
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Interfaces=org.kdevelop.ITestProvider
X-KDevelop-Mode=GUI
X-KDevelop-IRequired=org.kdevelop.PHPSupport

==> kdev-php-5.1.80.tar.xz: kdev-php-5.1.80/testprovider/kdevphpunitprovider.desktop.cmake <==
[Desktop Entry]
Type=Service
Exec=blubb
Comment=Finds and runs PHPUnit tests.
Comment[ar]=يعثر اختبارات PHPUnit ويشغّلها.
Comment[bs]=Traži i pokreće PHPUnit testove.
Comment[ca]=Cerca i executa proves del PHPUnit.
Comment[ca@valencia]=Busca i executa proves del PHPUnit.
Comment[da]=Finder og kører PHPUnit-tests.
Comment[de]=Sucht und führt PHPUnit-Tests aus.
Comment[el]=Βρίσκει και εκτελεί PHPUnit tests.
Comment[en_GB]=Finds and runs PHPUnit tests.
Comment[es]=Encuentra y ejecuta pruebas PHPUnit.
Comment[et]=PHPUniti testide leidmine ja käivitamine.
Comment[fi]=Etsii ja suorittaa PHPUnit-testejä
Comment[fr]=Trouve et exécute des tests « PHPUnit ».
Comment[ga]=Aimsigh agus rith tástálacha PHPUnit.
Comment[gl]=Atopa e executa probas de PHPUnit.
Comment[hu]=Megkeresi és lefuttatja a PHPUnit teszteket.
Comment[it]=Trova ed esegue i test PHPUnit
Comment[kk]=PHPUnit сынақтарды тауып жегу.
Comment[ko]=PHPUnit 테스트를 찾아서 실행합니다.
Comment[lt]=Randa ir vykdo PHPUnit testus.
Comment[mr]=पीएचपी-युनिट चाचण्या शोधतो व चालवतो.
Comment[nb]=Finner og kjører PHPUnit-tester.
Comment[nl]=Testen van PHPUnit vinden en uitvoeren.
Comment[pl]=Znajduje i uruchamia testy PHPUnit.
Comment[pt]=Procura e executa os testes do PHPUnit.
Comment[pt_BR]=Procura e executa os testes do PHPUnit.
Comment[ru]=Находит и запускает тесты PHPUnit
Comment[sk]=Nájde a spustí PHPUnit testy.
Comment[sl]=Najde in zažene preizkuse PHPUnit
Comment[sv]=Söker efter och kör PHPUnit-tester.
Comment[tr]=PHPUnit testlerini bulur ve çalıştırır.
Comment[uk]=Пошук і запуск перевірок PHPUnit.
Comment[x-test]=xxFinds and runs PHPUnit tests.xx
Comment[zh_CN]=查找并运行 PHPUnit 测试
Comment[zh_TW]=尋找並執行 PHPUnit 測試。
Name=PHPUnit Integration
Name[ar]=تكامل PHPUnit
Name[bs]=PHPUnit Integracija
Name[ca]=Integració del PHPUnit
Name[ca@valencia]=Integració del PHPUnit
Name[da]=Integration af PHPUnit
Name[de]=PHPUnit-Integration
Name[el]=PHPUnit Integration
Name[en_GB]=PHPUnit Integration
Name[es]=Integración de PHPUnit
Name[et]=PHPUniti lõimimine
Name[fi]=PHPUnit-integraatio
Name[fr]=Intégration de « PHPUnit »
Name[ga]=Comhtháthú PHPUnit
Name[gl]=Integración con PHPUnit
Name[hu]=PHPUnit integráció
Name[it]=Integrazione PHPUnit
Name[kk]=PHPUnit біріктіру
Name[ko]=PHPUnit 통합
Name[lt]=PHPUnit integracija
Name[mr]=पीएचपी-युनिट एकीकरण
Name[nb]=PHPUnit-integrering
Name[nl]=Integratie van PHPUnit
Name[pl]=Integracja PHPUnit
Name[pt]=Integração com o PHPUnit
Name[pt_BR]=Integração com o PHPUnit
Name[ru]=Интеграция PHPUnit
Name[sk]=Integrácia PHPUnit
Name[sl]=Podpora PHPUnit
Name[sv]=Integrering av PHPUnit
Name[tr]=PHPUnit Bütünleşmesi
Name[ug]=PHPUnit يۈرۈشلەشتۈرۈلۈشى
Name[uk]=Інтеграція PHPUnit
Name[x-test]=xxPHPUnit Integrationxx
Name[zh_CN]=PHPUnit 集成
Name[zh_TW]=PHPUnit 整合
GenericName=PHPUnit Integration
GenericName[ar]=تكامل PHPUnit
GenericName[bs]=PHPUnit Integracija
GenericName[ca]=Integració del PHPUnit
GenericName[ca@valencia]=Integració del PHPUnit
GenericName[da]=Integration af PHPUnit
GenericName[de]=PHPUnit-Integration
GenericName[el]=PHPUnit Integration
GenericName[en_GB]=PHPUnit Integration
GenericName[es]=Integración de PHPUnit
GenericName[et]=PHPUniti lõimimine
GenericName[fi]=PHPUnit-integraatio
GenericName[fr]=Intégration de « PHPUnit »
GenericName[ga]=Comhtháthú PHPUnit
GenericName[gl]=Integración con PHPUnit
GenericName[hu]=PHPUnit integráció
GenericName[it]=Integrazione PHPUnit
GenericName[kk]=PHPUnit біріктіру
GenericName[ko]=PHPUnit 통합
GenericName[lt]=PHPUnit integracija
GenericName[mr]=पीएचपी-युनिट एकीकरण
GenericName[nb]=PHPUnit-integrering
GenericName[nl]=Integratie van PHPUnit
GenericName[pl]=Integracja PHPUnit
GenericName[pt]=Integração com o PHPUnit
GenericName[pt_BR]=Integração com o PHPUnit
GenericName[ru]=Интеграция PHPUnit
GenericName[sk]=Integrácia PHPUnit
GenericName[sl]=Podpora PHPUnit
GenericName[sv]=Integrering av PHPUnit
GenericName[tr]=PHPUnit Bütünleşmesi
GenericName[ug]=PHPUnit يۈرۈشلەشتۈرۈلۈشى
GenericName[uk]=Інтеграція PHPUnit
GenericName[x-test]=xxPHPUnit Integrationxx
GenericName[zh_CN]=PHPUnit 集成
GenericName[zh_TW]=PHPUnit 整合
Icon=php
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevplatform/@KDEV_PLUGIN_VERSION@/kdevphpunitprovider
X-KDE-PluginInfo-Name=kdevphpunitprovider
X-KDE-PluginInfo-Author=Miha Čančula
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Testing
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDevelop-Interfaces=org.kdevelop.ITestProvider
X-KDevelop-Mode=GUI
X-KDevelop-IRequired=org.kdevelop.PHPSupport
